==> dcoupon_sdk_flutter_package-5.1.0.tar.gz: example/lib/translations.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart' show rootBundle;

class TranslationsDelegate extends LocalizationsDelegate<Translations> {
  const TranslationsDelegate();

  List<Locale> get supportedLocales {
    //MUST update Info tab on iOS Runner project according to this
    return const <Locale>[
      Locale('en'),
      Locale('es'),
      Locale('ca', 'ES'),
      Locale('gl', 'ES'),
      Locale('pt'),
    ];
  }

  @override
  bool isSupported(Locale locale) {
    for (var supportedLocale in supportedLocales) {
      if (supportedLocale.languageCode == locale.languageCode) {
        return true;
      }
    }
    return false;
  }

  @override
  Future<Translations> load(Locale locale) => Translations.load(locale);

  @override
  bool shouldReload(TranslationsDelegate old) => false;
}

class Translations {
  Translations(this.locale);

  static const TranslationsDelegate delegate = TranslationsDelegate();

  final Locale locale;
  static Map<dynamic, dynamic>? _localizedValues;

  static Translations? of(BuildContext context) {
    return Localizations.of<Translations>(context, Translations);
  }

  String text(String key) {
    return _localizedValues![key] ?? '** $key not found';
  }

  static Future<Translations> load(Locale locale) async {
    Translations translations = new Translations(locale);
    try {
      String jsonContent = await rootBundle
          .loadString("lib/assets/i18n/${locale.languageCode}.json");
      _localizedValues = json.decode(jsonContent);
    } catch (ex) {
      final defaultLanguage = 'es';
      print("Translations.load() error: " + ex.toString());
      String jsonContent = await rootBundle
          .loadString("lib/assets/i18n/${defaultLanguage}.json");
      _localizedValues = json.decode(jsonContent);
    }
    return translations;
  }

  get currentLanguage => locale.languageCode;
}

==> dcoupon_sdk_flutter_package-8.0.1.tar.gz: example/lib/translations.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart' show rootBundle;

class TranslationsDelegate extends LocalizationsDelegate<Translations> {
  const TranslationsDelegate();

  List<Locale> get supportedLocales {
    //MUST update Info tab on iOS Runner project according to this
    return const <Locale>[
      Locale('en'),
      Locale('es'),
      Locale('ca', 'ES'),
      Locale('gl', 'ES'),
      Locale('pt'),
    ];
  }

  @override
  bool isSupported(Locale locale) {
    for (var supportedLocale in supportedLocales) {
      if (supportedLocale.languageCode == locale.languageCode) {
        return true;
      }
    }
    return false;
  }

  @override
  Future<Translations> load(Locale locale) => Translations.load(locale);

  @override
  bool shouldReload(TranslationsDelegate old) => false;
}

class Translations {
  Translations(this.locale);

  static const TranslationsDelegate delegate = TranslationsDelegate();

  final Locale locale;
  static Map<dynamic, dynamic>? _localizedValues;

  static Translations? of(BuildContext context) {
    return Localizations.of<Translations>(context, Translations);
  }

  String text(String key) {
    return _localizedValues![key] ?? '** $key not found';
  }

  static Future<Translations> load(Locale locale) async {
    Translations translations = new Translations(locale);
    try {
      String jsonContent = await rootBundle
          .loadString("lib/assets/i18n/${locale.languageCode}.json");
      _localizedValues = json.decode(jsonContent);
    } catch (ex) {
      final defaultLanguage = 'es';
      print("Translations.load() error: " + ex.toString());
      String jsonContent = await rootBundle
          .loadString("lib/assets/i18n/$defaultLanguage.json");
      _localizedValues = json.decode(jsonContent);
    }
    return translations;
  }

  get currentLanguage => locale.languageCode;
}
